@@ -247,7 +247,7 @@ void makefixed()
  */
 local int updatewindow(strm, end, copy)
 z_streamp strm;
-const Bytef *end;
+const Byte FAR *end;
 unsigned copy;
 {
     struct inflate_state FAR *state;
@@ -772,6 +772,11 @@ int flush;
             if (left == 0) goto inf_leave;
             copy = out - left;
             if (state->offset > copy) {         /* copy from window */
+                if (state->window == NULL) {
+                    strm->msg = (char *)"try to copy from null window buffer!";
+                    state->mode = BAD;
+                    break;
+                }
                 copy = state->offset - copy;
                 if (copy > state->whave) {
                     if (state->sane) {
